==> servicecatalog-model-6.3.0-sources.jar: io/fabric8/servicecatalog/api/model/ServiceBrokerListFluentImpl.java <==
package io.fabric8.servicecatalog.api.model;

import io.fabric8.kubernetes.api.builder.VisitableBuilder;
import java.lang.SuppressWarnings;
import io.fabric8.kubernetes.api.builder.Nested;
import java.util.ArrayList;
import java.lang.String;
import io.fabric8.kubernetes.api.model.ListMeta;
import java.util.function.Predicate;
import java.lang.Integer;
import java.lang.Deprecated;
import io.fabric8.kubernetes.api.builder.BaseFluent;
import java.lang.Long;
import java.util.Iterator;
import java.util.Collection;
import java.lang.Object;
import java.util.List;
import java.lang.Boolean;

 /**
  * Generated
  */
  @SuppressWarnings(value = "unchecked")
  public class ServiceBrokerListFluentImpl<A extends ServiceBrokerListFluent<A>> extends BaseFluent<A> implements ServiceBrokerListFluent<A>{
  public ServiceBrokerListFluentImpl() {
  }
  public ServiceBrokerListFluentImpl(ServiceBrokerList instance) {
    this.withApiVersion(instance.getApiVersion()); 
    this.withItems(instance.getItems()); 
    this.withKind(instance.getKind()); 
    this.withMetadata(instance.getMetadata()); 
  }
  private String apiVersion;
  private ArrayList<ServiceBrokerBuilder> items = new ArrayList<ServiceBrokerBuilder>();
  private String kind;
  private ListMeta metadata;
  public String getApiVersion() {
    return this.apiVersion;
  }
  public A withApiVersion(String apiVersion) {
    this.apiVersion=apiVersion; return (A) this;
  }
  public Boolean hasApiVersion() {
    return this.apiVersion != null;
  }
  public A addToItems(Integer index,ServiceBroker item) {
    if (this.items == null) {this.items = new ArrayList<ServiceBrokerBuilder>();}
    ServiceBrokerBuilder builder = new ServiceBrokerBuilder(item);_visitables.get("items").add(index >= 0 ? index : _visitables.get("items").size(), builder);this.items.add(index >= 0 ? index : items.size(), builder); return (A)this;
  }
  public A setToItems(Integer index,ServiceBroker item) {
    if (this.items == null) {this.items = new ArrayList<ServiceBrokerBuilder>();}
    ServiceBrokerBuilder builder = new ServiceBrokerBuilder(item);
    if (index < 0 || index >= _visitables.get("items").size()) { _visitables.get("items").add(builder); } else { _visitables.get("items").set(index, builder);}
    if (index < 0 || index >= items.size()) { items.add(builder); } else { items.set(index, builder);}
     return (A)this;
  }
  public A addToItems(io.fabric8.servicecatalog.api.model.ServiceBroker... items) {
    if (this.items == null) {this.items = new ArrayList<ServiceBrokerBuilder>();}
    for (ServiceBroker item : items) {ServiceBrokerBuilder builder = new ServiceBrokerBuilder(item);_visitables.get("items").add(builder);this.items.add(builder);} return (A)this;
  }
  public A addAllToItems(Collection<ServiceBroker> items) {
    if (this.items == null) {this.items = new ArrayList<ServiceBrokerBuilder>();}
    for (ServiceBroker item : items) {ServiceBrokerBuilder builder = new ServiceBrokerBuilder(item);_visitables.get("items").add(builder);this.items.add(builder);} return (A)this;
  }
  public A removeFromItems(io.fabric8.servicecatalog.api.model.ServiceBroker... items) {
    for (ServiceBroker item : items) {ServiceBrokerBuilder builder = new ServiceBrokerBuilder(item);_visitables.get("items").remove(builder);if (this.items != null) {this.items.remove(builder);}} return (A)this;
  }
  public A removeAllFromItems(Collection<ServiceBroker> items) {
    for (ServiceBroker item : items) {ServiceBrokerBuilder builder = new ServiceBrokerBuilder(item);_visitables.get("items").remove(builder);if (this.items != null) {this.items.remove(builder);}} return (A)this;
  }
  public A removeMatchingFromItems(Predicate<ServiceBrokerBuilder> predicate) {
    if (items == null) return (A) this;
    final Iterator<ServiceBrokerBuilder> each = items.iterator();
    final List visitables = _visitables.get("items");
    while (each.hasNext()) {
      ServiceBrokerBuilder builder = each.next();
      if (predicate.test(builder)) {
        visitables.remove(builder);
        each.remove();
      }
    }
    return (A)this;
  }
  
  /**
   * This method has been deprecated, please use method buildItems instead.
   * @return The buildable object.
   */
  @Deprecated
  public List<ServiceBroker> getItems() {
    return items != null ? build(items) : null;
  }
  public List<ServiceBroker> buildItems() {
    return items != null ? build(items) : null;
  }
  public ServiceBroker buildItem(Integer index) {
    return this.items.get(index).build();
  }
  public ServiceBroker buildFirstItem() {
    return this.items.get(0).build();
  }
  public ServiceBroker buildLastItem() {
    return this.items.get(items.size() - 1).build();
  }
  public ServiceBroker buildMatchingItem(Predicate<ServiceBrokerBuilder> predicate) {
    for (ServiceBrokerBuilder item: items) { if(predicate.test(item)){ return item.build();} } return null;
  }
  public Boolean hasMatchingItem(Predicate<ServiceBrokerBuilder> predicate) {
    for (ServiceBrokerBuilder item: items) { if(predicate.test(item)){ return true;} } return false;
  }
  public A withItems(List<ServiceBroker> items) {
    if (this.items != null) { _visitables.get("items").removeAll(this.items);}
    if (items != null) {this.items = new ArrayList(); for (ServiceBroker item : items){this.addToItems(item);}} else { this.items = null;} return (A) this;
  }
  public A withItems(io.fabric8.servicecatalog.api.model.ServiceBroker... items) {
    if (this.items != null) {this.items.clear();}
    if (items != null) {for (ServiceBroker item :items){ this.addToItems(item);}} return (A) this;
  }
  public Boolean hasItems() {
    return items != null && !items.isEmpty();
  }
  public ServiceBrokerListFluent.ItemsNested<A> addNewItem() {
    return new ServiceBrokerListFluentImpl.ItemsNestedImpl();
  }
  public ServiceBrokerListFluent.ItemsNested<A> addNewItemLike(ServiceBroker item) {
    return new ServiceBrokerListFluentImpl.ItemsNestedImpl(-1, item);
  }
  public ServiceBrokerListFluent.ItemsNested<A> setNewItemLike(Integer index,ServiceBroker item) {
    return new ServiceBrokerListFluentImpl.ItemsNestedImpl(index, item);
  }
  public ServiceBrokerListFluent.ItemsNested<A> editItem(Integer index) {
    if (items.size() <= index) throw new RuntimeException("Can't edit items. Index exceeds size.");
    return setNewItemLike(index, buildItem(index));
  }
  public ServiceBrokerListFluent.ItemsNested<A> editFirstItem() {
    if (items.size() == 0) throw new RuntimeException("Can't edit first items. The list is empty.");
    return setNewItemLike(0, buildItem(0));
  }
  public ServiceBrokerListFluent.ItemsNested<A> editLastItem() {
    int index = items.size() - 1;
    if (index < 0) throw new RuntimeException("Can't edit last items. The list is empty.");
    return setNewItemLike(index, buildItem(index));
  }
  public ServiceBrokerListFluent.ItemsNested<A> editMatchingItem(Predicate<ServiceBrokerBuilder> predicate) {
    int index = -1;
    for (int i=0;i<items.size();i++) { 
    if (predicate.test(items.get(i))) {index = i; break;}
    } 
    if (index < 0) throw new RuntimeException("Can't edit matching items. No match found.");
    return setNewItemLike(index, buildItem(index));
  }
  public String getKind() {
    return this.kind;
  }
  public A withKind(String kind) {
    this.kind=kind; return (A) this;
  }
  public Boolean hasKind() {
    return this.kind != null;
  }
  public ListMeta getMetadata() {
    return this.metadata;
  }
  public A withMetadata(ListMeta metadata) {
    this.metadata=metadata; return (A) this;
  }
  public Boolean hasMetadata() {
    return this.metadata != null;
  }
  public A withNewMetadata(String _continue,Long remainingItemCount,String resourceVersion,String selfLink) {
    return (A)withMetadata(new ListMeta(_continue, remainingItemCount, resourceVersion, selfLink));
  }
  public boolean equals(Object o) {
    if (this == o) return true;
    if (o == null || getClass() != o.getClass()) return false;
    ServiceBrokerListFluentImpl that = (ServiceBrokerListFluentImpl) o;
    if (apiVersion != null ? !apiVersion.equals(that.apiVersion) :that.apiVersion != null) return false;
    if (items != null ? !items.equals(that.items) :that.items != null) return false;
    if (kind != null ? !kind.equals(that.kind) :that.kind != null) return false;
    if (metadata != null ? !metadata.equals(that.metadata) :that.metadata != null) return false;
    return true;
  }
  public int hashCode() {
    return java.util.Objects.hash(apiVersion,  items,  kind,  metadata,  super.hashCode());
  }
  public String toString() {
    StringBuilder sb = new StringBuilder();
    sb.append("{");
    if (apiVersion != null) { sb.append("apiVersion:"); sb.append(apiVersion + ","); }
    if (items != null && !items.isEmpty()) { sb.append("items:"); sb.append(items + ","); }
    if (kind != null) { sb.append("kind:"); sb.append(kind + ","); }
    if (metadata != null) { sb.append("metadata:"); sb.append(metadata); }
    sb.append("}");
    return sb.toString();
  }
  class ItemsNestedImpl<N> extends ServiceBrokerFluentImpl<ServiceBrokerListFluent.ItemsNested<N>> implements ServiceBrokerListFluent.ItemsNested<N>,Nested<N>{
    ItemsNestedImpl(Integer index,ServiceBroker item) {
      this.index = index;
      this.builder = new ServiceBrokerBuilder(this, item);
    }
    ItemsNestedImpl() {
      this.index = -1;
      this.builder = new ServiceBrokerBuilder(this);
    }
    ServiceBrokerBuilder builder;
    Integer index;
    public N and() {
      return (N) ServiceBrokerListFluentImpl.this.setToItems(index,builder.build());
    }
    public N endItem() {
      return and();
    }
    
  }
  
}

==> servicecatalog-model-6.7.2-sources.jar: io/fabric8/servicecatalog/api/model/ServiceBrokerListFluentImpl.java <==
package io.fabric8.servicecatalog.api.model;

import io.fabric8.kubernetes.api.builder.VisitableBuilder;
import java.lang.SuppressWarnings;
import io.fabric8.kubernetes.api.builder.Nested;
import java.util.ArrayList;
import java.lang.String;
import io.fabric8.kubernetes.api.model.ListMeta;
import java.util.function.Predicate;
import java.lang.Deprecated;
import io.fabric8.kubernetes.api.builder.BaseFluent;
import java.lang.Long;
import java.util.Iterator;
import java.util.Collection;
import java.lang.Object;
import java.util.List;
import java.lang.Boolean;

 /**
  * Generated
  */
  @SuppressWarnings(value = "unchecked")
  public class ServiceBrokerListFluentImpl<A extends ServiceBrokerListFluent<A>> extends BaseFluent<A> implements ServiceBrokerListFluent<A>{
  public ServiceBrokerListFluentImpl() {
  }
  public ServiceBrokerListFluentImpl(ServiceBrokerList instance) {
    if (instance != null) {
      this.withApiVersion(instance.getApiVersion());
      this.withItems(instance.getItems());
      this.withKind(instance.getKind());
      this.withMetadata(instance.getMetadata());
    }
  }
  private String apiVersion;
  private ArrayList<ServiceBrokerBuilder> items = new ArrayList<ServiceBrokerBuilder>();
  private String kind;
  private ListMeta metadata;
  public String getApiVersion() {
    return this.apiVersion;
  }
  public A withApiVersion(String apiVersion) {
    this.apiVersion=apiVersion; return (A) this;
  }
  public Boolean hasApiVersion() {
    return this.apiVersion != null;
  }
  public A addToItems(int index,ServiceBroker item) {
    if (this.items == null) {this.items = new ArrayList<ServiceBrokerBuilder>();}
    ServiceBrokerBuilder builder = new ServiceBrokerBuilder(item);
    if (index < 0 || index >= items.size()) { _visitables.get("items").add(builder); items.add(builder); } else { _visitables.get("items").add(index, builder); items.add(index, builder);}
    return (A)this;
  }
  public A setToItems(int index,ServiceBroker item) {
    if (this.items == null) {this.items = new ArrayList<ServiceBrokerBuilder>();}
    ServiceBrokerBuilder builder = new ServiceBrokerBuilder(item);
    if (index < 0 || index >= items.size()) { _visitables.get("items").add(builder); items.add(builder); } else { _visitables.get("items").set(index, builder); items.set(index, builder);}
    return (A)this;
  }
  public A addToItems(io.fabric8.servicecatalog.api.model.ServiceBroker... items) {
    if (this.items == null) {this.items = new ArrayList<ServiceBrokerBuilder>();}
    for (ServiceBroker item : items) {ServiceBrokerBuilder builder = new ServiceBrokerBuilder(item);_visitables.get("items").add(builder);this.items.add(builder);} return (A)this;
  }
  public A addAllToItems(Collection<ServiceBroker> items) {
    if (this.items == null) {this.items = new ArrayList<ServiceBrokerBuilder>();}
    for (ServiceBroker item : items) {ServiceBrokerBuilder builder = new ServiceBrokerBuilder(item);_visitables.get("items").add(builder);this.items.add(builder);} return (A)this;
  }
  public A removeFromItems(io.fabric8.servicecatalog.api.model.ServiceBroker... items) {
    for (ServiceBroker item : items) {ServiceBrokerBuilder builder = new ServiceBrokerBuilder(item);_visitables.get("items").remove(builder);if (this.items != null) {this.items.remove(builder);}} return (A)this;
  }
  public A removeAllFromItems(Collection<ServiceBroker> items) {
    for (ServiceBroker item : items) {ServiceBrokerBuilder builder = new ServiceBrokerBuilder(item);_visitables.get("items").remove(builder);if (this.items != null) {this.items.remove(builder);}} return (A)this;
  }
  public A removeMatchingFromItems(Predicate<ServiceBrokerBuilder> predicate) {
    if (items == null) return (A) this;
    final Iterator<ServiceBrokerBuilder> each = items.iterator();
    final List visitables = _visitables.get("items");
    while (each.hasNext()) {
      ServiceBrokerBuilder builder = each.next();
      if (predicate.test(builder)) {
        visitables.remove(builder);
        each.remove();
      }
    }
    return (A)this;
  }
  
  /**
   * This method has been deprecated, please use method buildItems instead.
   * @return The buildable object.
   */
  @Deprecated
  public List<ServiceBroker> getItems() {
    return items != null ? build(items) : null;
  }
  public List<ServiceBroker> buildItems() {
    return items != null ? build(items) : null;
  }
  public ServiceBroker buildItem(int index) {
    return this.items.get(index).build();
  }
  public ServiceBroker buildFirstItem() {
    return this.items.get(0).build();
  }
  public ServiceBroker buildLastItem() {
    return this.items.get(items.size() - 1).build();
  }
  public ServiceBroker buildMatchingItem(Predicate<ServiceBrokerBuilder> predicate) {
    for (ServiceBrokerBuilder item: items) { if(predicate.test(item)){ return item.build();} } return null;
  }
  public Boolean hasMatchingItem(Predicate<ServiceBrokerBuilder> predicate) {
    for (ServiceBrokerBuilder item: items) { if(predicate.test(item)){ return true;} } return false;
  }
  public A withItems(List<ServiceBroker> items) {
    if (this.items != null) { _visitables.get("items").clear();}
    if (items != null) {this.items = new ArrayList(); for (ServiceBroker item : items){this.addToItems(item);}} else { this.items = null;} return (A) this;
  }
  public A withItems(io.fabric8.servicecatalog.api.model.ServiceBroker... items) {
    if (this.items != null) {this.items.clear(); _visitables.remove("items"); }
    if (items != null) {for (ServiceBroker item :items){ this.addToItems(item);}} return (A) this;
  }
  public Boolean hasItems() {
    return items != null && !items.isEmpty();
  }
  public ServiceBrokerListFluentImpl.ItemsNested<A> addNewItem() {
    return new ServiceBrokerListFluentImpl.ItemsNestedImpl();
  }
  public ServiceBrokerListFluentImpl.ItemsNested<A> addNewItemLike(ServiceBroker item) {
    return new ServiceBrokerListFluentImpl.ItemsNestedImpl(-1, item);
  }
  public ServiceBrokerListFluentImpl.ItemsNested<A> setNewItemLike(int index,ServiceBroker item) {
    return new ServiceBrokerListFluentImpl.ItemsNestedImpl(index, item);
  }
  public ServiceBrokerListFluentImpl.ItemsNested<A> editItem(int index) {
    if (items.size() <= index) throw new RuntimeException("Can't edit items. Index exceeds size.");
    return setNewItemLike(index, buildItem(index));
  }
  public ServiceBrokerListFluentImpl.ItemsNested<A> editFirstItem() {
    if (items.size() == 0) throw new RuntimeException("Can't edit first items. The list is empty.");
    return setNewItemLike(0, buildItem(0));
  }
  public ServiceBrokerListFluentImpl.ItemsNested<A> editLastItem() {
    int index = items.size() - 1;
    if (index < 0) throw new RuntimeException("Can't edit last items. The list is empty.");
    return setNewItemLike(index, buildItem(index));
  }
  public ServiceBrokerListFluentImpl.ItemsNested<A> editMatchingItem(Predicate<ServiceBrokerBuilder> predicate) {
    int index = -1;
    for (int i=0;i<items.size();i++) { 
    if (predicate.test(items.get(i))) {index = i; break;}
    } 
    if (index < 0) throw new RuntimeException("Can't edit matching items. No match found.");
    return setNewItemLike(index, buildItem(index));
  }
  public String getKind() {
    return this.kind;
  }
  public A withKind(String kind) {
    this.kind=kind; return (A) this;
  }
  public Boolean hasKind() {
    return this.kind != null;
  }
  public ListMeta getMetadata() {
    return this.metadata;
  }
  public A withMetadata(ListMeta metadata) {
    this.metadata=metadata; return (A) this;
  }
  public Boolean hasMetadata() {
    return this.metadata != null;
  }
  public A withNewMetadata(String _continue,Long remainingItemCount,String resourceVersion,String selfLink) {
    return (A)withMetadata(new ListMeta(_continue, remainingItemCount, resourceVersion, selfLink));
  }
  public boolean equals(Object o) {
    if (this == o) return true;
    if (o == null || getClass() != o.getClass()) return false;
    if (!super.equals(o)) return false;
    ServiceBrokerListFluentImpl that = (ServiceBrokerListFluentImpl) o;
    if (!java.util.Objects.equals(apiVersion, that.apiVersion)) return false;

    if (!java.util.Objects.equals(items, that.items)) return false;

    if (!java.util.Objects.equals(kind, that.kind)) return false;

    if (!java.util.Objects.equals(metadata, that.metadata)) return false;

    return true;
  }
  public int hashCode() {
    return java.util.Objects.hash(apiVersion,  items,  kind,  metadata,  super.hashCode());
  }
  public String toString() {
    StringBuilder sb = new StringBuilder();
    sb.append("{");
    if (apiVersion != null) { sb.append("apiVersion:"); sb.append(apiVersion + ","); }
    if (items != null) { sb.append("items:"); sb.append(items + ","); }
    if (kind != null) { sb.append("kind:"); sb.append(kind + ","); }
    if (metadata != null) { sb.append("metadata:"); sb.append(metadata); }
    sb.append("}");
    return sb.toString();
  }
  class ItemsNestedImpl<N> extends ServiceBrokerFluentImpl<ServiceBrokerListFluentImpl.ItemsNested<N>> implements ServiceBrokerListFluentImpl.ItemsNested<N>,Nested<N>{
    ItemsNestedImpl(int index,ServiceBroker item) {
      this.index = index;
      this.builder = new ServiceBrokerBuilder(this, item);
    }
    ItemsNestedImpl() {
      this.index = -1;
      this.builder = new ServiceBrokerBuilder(this);
    }
    ServiceBrokerBuilder builder;
    int index;
    public N and() {
      return (N) ServiceBrokerListFluentImpl.this.setToItems(index,builder.build());
    }
    public N endItem() {
      return and();
    }
    
  }
  
}
